/*
 * Copyright 2010 James Pether Sörling
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: AggregatedBugDataContainer.java 5442 2011-04-26 19:16:26Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.impl/src/main/java/com/hack23/cia/service/impl/AggregatedBugDataContainer.java $
 */
package com.hack23.cia.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.googlecode.ehcache.annotations.Cacheable;
import com.hack23.cia.model.external.itsyourparliament.mepinfo.impl.MepinfoEuElement;
import com.hack23.cia.model.external.riksdagen.person.impl.PersonData;
import com.hack23.cia.model.internal.application.data.impl.AggregatedBugData;
import com.hack23.cia.model.internal.application.data.impl.BugMetaDataType;
import com.hack23.cia.service.api.DataContainer;
import com.hack23.cia.service.data.api.MepinfoEuElementDAO;
import com.hack23.cia.service.data.api.PersonDataDAO;

/**
 * The Class AggregatedBugDataContainer.
 */
@Component(value = "AggregatedBugDataContainer")
@Transactional(propagation = Propagation.SUPPORTS)
public final class AggregatedBugDataContainer implements
		DataContainer<AggregatedBugData, String> {

	/** The mepinfo eu element dao. */
	@Autowired
	private MepinfoEuElementDAO mepinfoEuElementDAO;

	/** The person data dao. */
	@Autowired
	private PersonDataDAO personDataDAO;

	/*
	 * (non-Javadoc)
	 *
	 * @see com.hack23.cia.service.api.DataContainer#getAll()
	 */
	@Override
	@Cacheable(cacheName = "AggregatedBugData")
	public List<AggregatedBugData> getAll() {
		final List<AggregatedBugData> result = new ArrayList<AggregatedBugData>();

		for (final PersonData element : personDataDAO.getAll()) {
			final AggregatedBugData aggregatedBugData = new AggregatedBugData();
			aggregatedBugData.setType(BugMetaDataType.SWEDISH_POLITICIAN);
			aggregatedBugData.setSweden(element);
			aggregatedBugData.setCountry("Sweden");
			aggregatedBugData.setName(element.getFirstName() + " "
					+ element.getLastName());
			aggregatedBugData.setParty(element.getParty());
			aggregatedBugData.setId(element.getId());
			aggregatedBugData.setKey(aggregatedBugData.getCountry() + "/"
					+ aggregatedBugData.getParty() + "/"
					+ aggregatedBugData.getId() + "/"
					+ aggregatedBugData.getName());
			result.add(aggregatedBugData);
		}

		for (final MepinfoEuElement element : mepinfoEuElementDAO.getAll()) {
			final AggregatedBugData aggregatedBugData = new AggregatedBugData();
			aggregatedBugData.setType(BugMetaDataType.EU_POLITICIAN);
			aggregatedBugData.setEu(element);
			aggregatedBugData.setCountry(element.getCountry().trim());
			aggregatedBugData.setName(element.getFullname().trim());
			aggregatedBugData.setParty(element.getParty().trim());
			aggregatedBugData.setId(element.getHjid().toString().trim());
			aggregatedBugData.setKey(aggregatedBugData.getCountry().trim()
					+ "/" + aggregatedBugData.getParty().trim() + "/"
					+ aggregatedBugData.getId().trim() + "/"
					+ aggregatedBugData.getName().trim());
			result.add(aggregatedBugData);
		}

		return result;

	}

	/*
	 * (non-Javadoc)
	 *
	 * @see com.hack23.cia.service.api.DataContainer#load(java.io.Serializable)
	 */
	@Override
	@Cacheable(cacheName = "AggregatedBugData")
	public AggregatedBugData load(final String id) {
		if (id != null) {
			for (final AggregatedBugData data : getAll()) {
				if (data.getKey().equals(id)) {
					return data;
				}
			}
		}
		return null;
	}

}
