/*
 * Copyright 2010 James Pether Sörling
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: AggregatedCountryDataContainer.java 5442 2011-04-26 19:16:26Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.impl/src/main/java/com/hack23/cia/service/impl/AggregatedCountryDataContainer.java $
 */
package com.hack23.cia.service.impl;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.googlecode.ehcache.annotations.Cacheable;
import com.hack23.cia.model.external.itsyourparliament.countries.impl.Countrydetails;
import com.hack23.cia.model.external.worldbank.countries.impl.CountryElement;
import com.hack23.cia.model.internal.application.data.impl.AggregatedCountryData;
import com.hack23.cia.model.internal.application.data.impl.CountryMetaDataType;
import com.hack23.cia.service.api.DataContainer;
import com.hack23.cia.service.data.api.CountryElementDAO;
import com.hack23.cia.service.data.api.CountrydetailsDAO;

/**
 * The Class AggregatedCountryDataContainer.
 */
@Component(value = "AggregatedCountryDataContainer")
@Transactional(propagation = Propagation.SUPPORTS)
public final class AggregatedCountryDataContainer implements
		DataContainer<AggregatedCountryData, String> {

	/** The country element dao. */
	@Autowired
	private CountryElementDAO countryElementDAO;

	/** The countryinfo eu element dao. */
	@Autowired
	private CountrydetailsDAO countryinfoEuElementDAO;

	/*
	 * (non-Javadoc)
	 *
	 * @see com.hack23.cia.service.api.DataContainer#getAll()
	 */
	@Override
	@Cacheable(cacheName = "AggregatedCountryData")
	public List<AggregatedCountryData> getAll() {
		final List<AggregatedCountryData> result = new ArrayList<AggregatedCountryData>();
		final Map<String, Countrydetails> euMap = new HashMap<String, Countrydetails>();

		for (final Countrydetails element : countryinfoEuElementDAO.getAll()) {
			euMap.put(element.getCountrycode().toLowerCase().trim(), element);
		}

		for (final CountryElement element : countryElementDAO.getAll()) {
			final AggregatedCountryData aggregatedCountryData = new AggregatedCountryData();
			aggregatedCountryData.setCountry(element);

			if (element.getLongitude() != null
					&& element.getLongitude().trim().length() > 0) {

				if (euMap.containsKey(element.getIso2Code().toLowerCase()
						.trim())) {
					aggregatedCountryData.setEuMember(euMap.get(element
							.getIso2Code().toLowerCase().trim()));
					aggregatedCountryData
							.setType(CountryMetaDataType.ITSYOUR_PARLIAMENT);
				} else {
					aggregatedCountryData
							.setType(CountryMetaDataType.WORLDBANK_DATA);
				}

				result.add(aggregatedCountryData);
			}
		}
		return result;
	}

	/*
	 * (non-Javadoc)
	 *
	 * @see com.hack23.cia.service.api.DataContainer#load(java.io.Serializable)
	 */
	@Override
	@Cacheable(cacheName = "AggregatedCountryData")
	public AggregatedCountryData load(final String id) {
		if (id != null) {
			for (final AggregatedCountryData countryData : getAll()) {
				if (countryData.getCountry().getName().toLowerCase().trim()
						.equals(id.toLowerCase().trim())) {
					return countryData;
				}
			}
		}
		return null;
	}

}
