/*
 * Copyright 2010 James Pether Sörling
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: CommitteeProposalComponentDataContainer.java 5442 2011-04-26 19:16:26Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.impl/src/main/java/com/hack23/cia/service/impl/CommitteeProposalComponentDataContainer.java $
*/
package com.hack23.cia.service.impl;

import java.util.List;

import org.hibernate.Hibernate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.external.riksdagen.person.impl.PersonData;
import com.hack23.cia.service.api.DataContainer;
import com.hack23.cia.service.data.api.PersonDataDAO;

/**
 * The Class CommitteeProposalComponentDataContainer.
 */
@Component
@Transactional(propagation=Propagation.SUPPORTS)
public final class CommitteeProposalComponentDataContainer implements DataContainer<PersonData,String>{

	/** The person data dao. */
	@Autowired
	private PersonDataDAO personDataDAO;

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.DataContainer#getAll()
	 */
	@Override
	public List<PersonData> getAll() {
		final List<PersonData> all = personDataDAO.getAll();
		Hibernate.initialize(all);

		for (final PersonData load: all) {
			Hibernate.initialize(load.getPersonAssignmentData());
			Hibernate.initialize(load.getPersonAssignmentData().getAssignmentList());
			Hibernate.initialize(load.getPersonDetailData());
			Hibernate.initialize(load.getPersonDetailData().getDetailList());
		}

		return all;
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.DataContainer#load()
	 */
	@Override
	public PersonData load(final String id) {
		final PersonData load = personDataDAO.load(id);
		Hibernate.initialize(load.getPersonAssignmentData());
		Hibernate.initialize(load.getPersonAssignmentData().getAssignmentList());
		Hibernate.initialize(load.getPersonDetailData());
		Hibernate.initialize(load.getPersonDetailData().getDetailList());

		return load;
	}
}
