/*
 * Copyright 2010 James Pether Sörling
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: DataSummaryDataContainer.java 5442 2011-04-26 19:16:26Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.impl/src/main/java/com/hack23/cia/service/impl/DataSummaryDataContainer.java $
*/
package com.hack23.cia.service.impl;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import com.hack23.cia.model.external.riksdagen.person.impl.PersonData;
import com.hack23.cia.model.external.riksdagen.person.impl.RoleStatus;
import com.hack23.cia.model.external.riksdagen.person.impl.SexType;
import com.hack23.cia.service.api.DataContainer;
import com.hack23.cia.service.api.DataSummary;
import com.hack23.cia.service.api.DataSummary.DataSummaryId;
import com.hack23.cia.service.data.api.CommitteeProposalComponentDataDAO;
import com.hack23.cia.service.data.api.DocumentContentDataDAO;
import com.hack23.cia.service.data.api.DocumentElementDAO;
import com.hack23.cia.service.data.api.DocumentStatusContainerDAO;
import com.hack23.cia.service.data.api.PersonDataDAO;
import com.hack23.cia.service.data.api.VoteDataDAO;

/**
 * The Class DataSummaryDataContainer.
 */
@Component(value="DataSummaryDataContainer")
@Transactional(propagation=Propagation.SUPPORTS)
public final class DataSummaryDataContainer implements DataContainer<DataSummary,DataSummaryId>{

	/** The committee proposal component data dao. */
	@Autowired
	private CommitteeProposalComponentDataDAO committeeProposalComponentDataDAO;

	/** The Document content data dao. */
	@Autowired
	private DocumentContentDataDAO DocumentContentDataDAO;

	/** The document element dao. */
	@Autowired
	private DocumentElementDAO documentElementDAO;

	/** The document status container dao. */
	@Autowired
	private DocumentStatusContainerDAO documentStatusContainerDAO;

	/** The person data dao. */
	@Autowired
	private PersonDataDAO personDataDAO;

	/** The Vote data dao. */
	@Autowired
	private VoteDataDAO VoteDataDAO;

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.DataContainer#getAll()
	 */
	@Override
	public List<DataSummary> getAll() {
		final List<DataSummary> list = new ArrayList<DataSummary>();
		list.add(load(null));
		return list;
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.DataContainer#load(java.io.Serializable)
	 */
	@Override
	public DataSummary load(final DataSummaryId id) {
		final Map<RoleStatus,Integer> roleStatusMap = new ConcurrentHashMap<RoleStatus, Integer>();

		final Map<SexType,Integer> sexMap = new ConcurrentHashMap<SexType, Integer>();

		final Map<Integer,Integer> bornYearMap = new ConcurrentHashMap<Integer, Integer>();

		final List<PersonData> all = personDataDAO.getAll();
		final long personSize=all.size();
		for(final RoleStatus role: RoleStatus.values()) {
			roleStatusMap.put(role, 0);
		}
		for(final SexType role: SexType.values()) {
			sexMap.put(role, 0);
		}

		for (final PersonData personData: all) {
			if ( personData.getStatus() != null) {
				roleStatusMap.put(personData.getStatus(), roleStatusMap.get(personData.getStatus())+1);
			}
			sexMap.put(personData.getGender(), sexMap.get(personData.getGender())+1);

			if (bornYearMap.get(personData.getBornYear())==null) {
				bornYearMap.put(personData.getBornYear(),1);
			} else {
				bornYearMap.put(personData.getBornYear(),personData.getBornYear() + 1);
			}
		}

		return new DataSummary(personSize,VoteDataDAO.getSize(),VoteDataDAO.getSize(),documentElementDAO.getSize(),DocumentContentDataDAO.getSize(),documentStatusContainerDAO.getSize(),committeeProposalComponentDataDAO.getSize(),roleStatusMap,sexMap,bornYearMap);
	}
}
