/*
 * Copyright 2010 James Pether Sörling
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *	$Id: TranslatorImpl.java 5442 2011-04-26 19:16:26Z pether $
 *  $HeadURL: https://cia.svn.sourceforge.net/svnroot/cia/tags/parent-pom-2011.05.31/service.impl/src/main/java/com/hack23/cia/service/impl/TranslatorImpl.java $
*/
package com.hack23.cia.service.impl;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.google.api.translate.Language;
import com.googlecode.ehcache.annotations.Cacheable;
import com.hack23.cia.service.api.Translator;

/**
 * The Class TranslatorImpl.
 */
@Service(value = "Translator")
public final class TranslatorImpl implements Translator {

	/** The translator service. */
	@Autowired
	private TranslatorService translatorService;

	/** The Constant STANDARD_PROTOCOL. */
	public static final Language STANDARD_PROTOCOL = Language.ENGLISH;

	/** The Constant SWEDISH_LANGUAGE. */
	public static final Language SWEDISH_LANGUAGE = Language.SWEDISH;

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.Translator#translate(java.lang.String, com.google.api.translate.Language, com.google.api.translate.Language)
	 */
	@Override
	@Cacheable(cacheName = "Translations")
	public String translate(final String text, final Language from,
			final Language to) {

		if (from.equals(to)) {
			return text;
		}
		return translatorService.getTranslation(text, from, to);
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.Translator#translateFromStandardProtocol(java.lang.String, com.google.api.translate.Language)
	 */
	@Override
	@Cacheable(cacheName = "TranslationsToEnglish")
	public String translateFromStandardProtocol(final String text,
			final Language to) {
		return translate(text, STANDARD_PROTOCOL, to);
	}

	/* (non-Javadoc)
	 * @see com.hack23.cia.service.api.Translator#translateFromSwedish(java.lang.String, com.google.api.translate.Language)
	 */
	@Override
	@Cacheable(cacheName = "TranslationsFromSwedish")
	public String translateFromSwedish(final String text, final Language to) {
		return translate(text, SWEDISH_LANGUAGE, to);
	}

}
